pitchtools.register_chromatic_pitch_class_numbers_by_chromatic_pitch_number_aggregate
=====================================================================================

.. autofunction:: abjad.tools.pitchtools.register_chromatic_pitch_class_numbers_by_chromatic_pitch_number_aggregate.register_chromatic_pitch_class_numbers_by_chromatic_pitch_number_aggregate
